@@ -181,6 +181,8 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "This contact cannot be moved" : "此聯絡人無法移動",
+    "This contact cannot be grouped" : "此聯絡人無法加入群組",
     "Add contacts to groups" : "新增聯絡人到群組",
     "Move contacts to addressbook" : "將聯絡人移動到通訊錄",
     "Select groups" : "選取群組",
@@ -188,8 +190,6 @@ OC.L10N.register(
     "Selected contacts" : "已選取聯絡人",
     "Please note that only {count} of the {total} contacts can be added to a group" : "請注意：在 {total} 個聯絡人中，僅能新增 {count} 個至群組",
     "Please note that only {count} of the {total} contacts can be moved" : "請注意：在 {total} 個聯絡人中，僅能移動 {count} 個聯絡人",
-    "This contact cannot be grouped" : "此聯絡人無法加入群組",
-    "This contact cannot be moved" : "此聯絡人無法移動",
     "Move" : "Move",
     "from {addressbook}" : "來自 {addressbook}",
     "Confirm merging contacts" : "確認合併聯絡人",
@@ -254,6 +254,9 @@ OC.L10N.register(
     "Add contact in group" : "新增聯絡人到群組",
     "None" : "無",
     "Select option" : "選取選項",
+    "note" : "備註",
+    "email" : "電子郵件",
+    "send an email" : "傳送電子郵件",
     "Personal dates" : "個人日期",
     "Add property of this type" : "新增此類型的屬性",
     "Member" : "成員",
